use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
ARRAYn
Alders
AllUtils
Andy
BLOCK's
Champoux
DROLSKY
DROLSKY's
Dave
EXPR
Etheridge
Haskell
Jack
Jacoby
KEYFUNC
KVLIST
Karen
List
Olaf
PayPal
Ricardo
Rolsky
Rolsky's
Signes
Yanick
autarch
bsearchidx
drolsky
ether
firstidx
firstres
firstval
github
jacoby
keyvalue
lastidx
lastres
lastval
lib
maxstr
minmax
minstr
natatime
notall
olaf
onlyidx
onlyres
onlyval
pairfirst
pairgrep
pairkeys
pairmap
pairvalues
probability
probabilty
randomisation
rjbs
specialisations
thusly
uniq
uniqnum
uniqstr
unpairs
unselected
util
yanick
